"use strict";
/* eslint max-depth: ["error", 7] */
/* eslint max-params: ["error", 7] */
Object.defineProperty(exports, "__esModule", { value: true });
const cli_ux_1 = require("cli-ux");
const fs = require("fs");
const path = require("path");
const fsNdjson = require("fs-ndjson");
const searchIssues_1 = require("../jira/searchIssues");
const jiraUtils_1 = require("../misc/jiraUtils");
const id_1 = require("../../utils/misc/id");
/*
    Fetches all issues and potentially their children
*/
const fetchIssues = async (jql, teamName, categoryName, jiraConfig, cacheDir, useCache, toDate) => {
    cli_ux_1.default.action.start(`Fetching issues using JQL query: ${jql}`);
    let issues = [];
    // If cache is enabled we don't fetch initiatives twice on the same day
    let today = new Date();
    if (toDate !== undefined) {
        today = new Date(toDate);
    }
    const initiativesCache = path.join(cacheDir, `forecast-${id_1.getId(teamName)}-${id_1.getId(categoryName)}-${today
        .toJSON()
        .slice(0, 10)}.ndjson`);
    if (useCache && fs.existsSync(initiativesCache)) {
        issues = fsNdjson.readFileSync(initiativesCache);
        // eslint-disable-next-line no-negated-condition
    }
    else if (toDate !== undefined) {
        issues = [];
    }
    else {
        const issuesJira = await searchIssues_1.default(jiraConfig, jql, 'summary,status,' +
            jiraConfig.fields.points +
            ',' +
            jiraConfig.fields.originalPoints +
            ',issuetype,assignee');
        const issueFileStream = fs.createWriteStream(initiativesCache, {
            flags: 'w',
        });
        for (const issue of issuesJira) {
            const updatedIssue = Object.assign(Object.assign({}, issue), { host: jiraConfig.host, jql: jql, points: jiraUtils_1.returnTicketsPoints(issue, jiraConfig) });
            issueFileStream.write(JSON.stringify(jiraUtils_1.cleanIssue(updatedIssue)) + '\n');
            issues.push(jiraUtils_1.cleanIssue(updatedIssue));
        }
        issueFileStream.end();
    }
    cli_ux_1.default.action.stop(' done');
    return issues;
};
exports.default = fetchIssues;
