"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
  Contains a serie of method aimed at reducing the payload
*/
const simplifyAssignee = (issue) => {
    if (issue.fields.assignee !== null) {
        return {
            name: issue.fields.assignee.name,
            displayName: issue.fields.assignee.displayName,
        };
    }
    return null;
};
const simplifyIssue = (issue) => {
    return {
        id: issue.id,
        key: issue.key,
        summary: issue.fields.summary,
        closedAt: issue.closedAt,
        weekStart: issue.weekStart === undefined ? null : issue.weekStart,
        status: {
            name: issue.fields.status.name,
            category: issue.fields.status.statusCategory.name,
        },
        type: {
            name: issue.fields.issuetype.name,
            iconUrl: issue.fields.issuetype.iconUrl,
        },
        points: issue.points,
        metrics: issue.metrics === undefined ? null : issue.metrics,
        assignee: simplifyAssignee(issue),
    };
};
// Iteratively go through children to "simplify" them
const simplifyChildren = (issue) => {
    if (issue.isLeaf === true) {
        return simplifyIssue(issue);
    }
    return Object.assign(Object.assign({}, simplifyIssue(issue)), { children: issue.children.map((i) => simplifyChildren(i)) });
};
const optimizePayload = (payload) => {
    return payload.map((issue) => {
        return Object.assign(Object.assign({}, simplifyIssue(issue)), { metrics: issue.metrics, children: issue.children.map((c) => simplifyChildren(c)) });
    });
};
exports.default = optimizePayload;
